# `@salesforce-ux/sds-styling-hooks`

## About

Global Styling hooks use CSS custom properties which make it easy to customize application-wide styling.

### Relevant links

- **Non-normative Specifications**
  - [Global Styling Hooks](https://github.com/salesforce-ux/salesforce-design-system/blob/main/rfcs/text/0000-global-styling-hooks.md)
  - [Component Styling Hooks](https://github.com/salesforce-ux/salesforce-design-system/blob/main/rfcs/text/0000-component-styling-hooks.md)
- **Documentation**
  - [Styling Hooks Naming Conventions](https://github.com/salesforce-ux/salesforce-design-system/blob/main/docs/styling-hooks/naming_conventions.md)
  - [How to Style Your Component]()

## Installation

Use [npm][npm] to install the [SDS Styling Hooks](https://www.npmjs.com/package/@salesforce-ux/sds-styling-hooks):

```bash
npm install --save-dev @salesforce-ux/sds-styling-hooks
```

## Build

Make sure you have `lerna` installed globally before running the build command.

```bash
npm install -g lerna
```

Once installed, run:

```bash
lerna run build
```

The build process will generate 6 different file formats for consumption.

### JSON (`*.json`)
```json
{
  "PROP_NAME": "PROP_VALUE"
}
```
### Raw JSON (`*.raw.json`)
```js
{
  "props": {
    "PROP_NAME": {
      "value": "PROP_VALUE",
      "type": "PROP_TYPE",
      "category": "PROP_CATEGORY",
      /* additional metadata */
    }
  }
}
```
### Common JS (`*.js`)
```js
module.exports = {
  propName: "PROP_VALUE"
};
```
### ES Module (`*.js`)
```js
export const propName = "PROP_VALUE";
```
### Custom Properties scoped to `:root` (`*.css`)
```css
:root {
  --prop-name: PROP_VALUE;
}
```
### Custom Property Registration using [CSS Properties and Values API](https://drafts.css-houdini.org/css-properties-values-api-1/) (`*.js`)
```js
if (CSS.registerProperty) {
  CSS.registerProperty({
    name: "--prop-name",
    syntax: "PROP_SYNTAX",
    inherits: false,
    initialValue: "PROP_VALUE",
  });
}
```

## Usage

Coming Soon

[npm]: https://www.npmjs.com/